# /etc/profile.d/keychain.sh - calling keychain the Fedora way
# read in user's keychain settings or use defaults running keychain

# Don't do anything if we're already done.
[ -n "$KEYCHAIN_DONE" ] && return

USERHOME=`getent passwd $USER | cut -d: -f6`
if [ "$HOME" = "$USERHOME" -a -f "$HOME/.keychainrc" ]; then

    . $HOME/.keychainrc

    [ -n "$KCHOPTS" ] || KCHOPTS="--quiet"
    case $- in
	*i*) ;;
	*) KCHOPTS="$KCHOPTS --noask" ;;
    esac
    [ -n "$SSHKEYS" ] || SSHKEYS=`grep -l -e '[DRS]S[AH] PRIVATE KEY' \
							   $HOME/.ssh/*`
    [ -n "$GPGKEYS" ] || GPGKEYS=""

    if [ -n "$ZSH_VERSION" ] ; then
	keychain ${=KCHOPTS} ${=SSHKEYS} ${=GPGKEYS}
    else
	keychain $KCHOPTS $SSHKEYS $GPGKEYS
    fi

    HOST=`uname -n`
    [ -f $HOME/.keychain/$HOST-sh ] && \
	. $HOME/.keychain/$HOST-sh
    [ -f $HOME/.keychain/$HOST-sh-gpg ] && \
	. $HOME/.keychain/$HOST-sh-gpg

    unset KCHOPTS SSHKEYS GPGKEYS HOST

    KEYCHAIN_DONE=1
fi

unset USERHOME
